@@ -1,21 +1,17 @@
 from enum import Enum
-from pprint import pprint
-import warnings
 from typing import List, Tuple, Optional, Union
-
 import numpy as np
-from matplotlib import pyplot as plt
 
-from michael960lib.common import deprecated
 from torusgrid import fields as fd
 from torusgrid.fields import RealField2D
 from . import static
-from ..core.evolution import PFCMinimizer
 from .. import pfc
 
 
-
 def generate(na, nb):
+    """
+    Calculate angle and system size
+    """
     v1 = ((na+nb)*2*np.pi, (na-nb)*2*np.pi/np.sqrt(3))
     v2 = (-v1[1]*np.sqrt(3), v1[0]*np.sqrt(3))
 
@@ -26,7 +22,11 @@ def generate(na, nb):
 
     return theta, Lx, Ly
 
+
 def generate_minimal(na: int, nb: int) -> Tuple[float, float, float]:
+    """
+    Calculate angle and system size, with GCDs removed
+    """
     # diameter
     D = np.pi * 4 / np.sqrt(3)
 
@@ -51,11 +51,14 @@ def generate_minimal(na: int, nb: int) -> Tuple[float, float, float]:
 
     return theta, Lx, Ly
 
+
 class AutoDimMode(Enum):
     SCALE = 0
     SNAP = 1
 
-def generate_eps(na: int, nb: int, eps_str: str, 
+
+def generate_eps(
+        na: int, nb: int, eps_str: str, 
         NxNy: Union[Tuple[int, int], AutoDimMode]=AutoDimMode.SCALE,
         minimize: Optional[Tuple[float, int]]=None) -> Tuple[float, RealField2D, RealField2D]:
     theta, Lx, Ly = generate_minimal(na, nb)
@@ -70,16 +73,16 @@ def generate_eps(na: int, nb: int, eps_str: str,
     liq0 = static.get_relaxed_minimized_coexistent_unit_cell(eps_str, liquid=True)
 
     print(f'[olg] sol0 psibar = {sol0.psi.mean()}')
-    print(f'[olg] sol0 size = ({sol0.Lx}, {sol0.Ly})')
-    print(f'[olg] sol0 shape = ({sol0.Nx}, {sol0.Ny})')
+    print(f'[olg] sol0 size = ({sol0.lx}, {sol0.ly})')
+    print(f'[olg] sol0 shape = ({sol0.nx}, {sol0.ny})')
 
     mu = static.get_coexistent_mu_final(eps_str)
     eps = float(eps_str)
 
-    Lx0 = sol0.Lx
-    Ly0 = sol0.Ly
-    Nx0 = sol0.Nx
-    Ny0 = sol0.Ny
+    Lx0 = sol0.lx
+    Ly0 = sol0.ly
+    Nx0 = sol0.nx
+    Ny0 = sol0.ny
 
 
     _density = np.sqrt(Nx0*Ny0/Lx0/Ly0)
@@ -107,8 +110,8 @@ def generate_eps(na: int, nb: int, eps_str: str,
     liq = fd.RealField2D(Lx, Ly, Nx, Ny)
 
     
-    Xr = np.cos(theta) * sol.X - np.sin(theta) * sol.Y
-    Yr = np.sin(theta) * sol.X + np.cos(theta) * sol.Y
+    Xr = np.cos(theta) * sol.x - np.sin(theta) * sol.y
+    Yr = np.sin(theta) * sol.x + np.cos(theta) * sol.y
 
     Ir = (Xr / Lx0 * Nx0).astype(int) % Nx0
     Jr = (Yr / Ly0 * Ny0).astype(int) % Ny0
@@ -124,7 +127,6 @@ def generate_eps(na: int, nb: int, eps_str: str,
     print(f'[olg] sol shape = ({Nx}, {Ny})')
 
 
-
     dfmt = '[{system}][{label}][t={age:.2f}] f={f:.10f} F={F:.10f} omega={omega:.10f} Omega={Omega:.10f} psibar={psibar:.10f}'
     if minimize is not None:
         print(f'[olg] running mu-minimzation')
@@ -137,9 +139,9 @@ def generate_eps(na: int, nb: int, eps_str: str,
     print(f'[olg] sol size = ({Lx}, {Ly})')
     print(f'[olg] sol shape = ({Nx}, {Ny})')
 
-
     return theta, sol, liq
 
+
 def generate_from_field(
         na: int, nb: int, 
         sol0: RealField2D, liq0: RealField2D,
@@ -152,14 +154,14 @@ def generate_from_field(
     Lx *= f[0]
     Ly *= f[1]
 
-    Lx0 = sol0.Lx
-    Ly0 = sol0.Ly
-    Nx0 = sol0.Nx
-    Ny0 = sol0.Ny
+    Lx0 = sol0.lx
+    Ly0 = sol0.ly
+    Nx0 = sol0.nx
+    Ny0 = sol0.ny
 
     print('lattice generator')
-    print(f'solid resolution: ({sol0.Nx}, {sol0.Ny})')
-    print(f'solid size: {sol0.Lx}, {sol0.Ly})')
+    print(f'solid resolution: ({sol0.nx}, {sol0.ny})')
+    print(f'solid size: {sol0.lx}, {sol0.ly})')
 
     _density = np.sqrt(Nx0*Ny0/Lx0/Ly0)
 
@@ -182,12 +184,11 @@ def generate_from_field(
     except AssertionError:
         raise ValueError('NxNy must be a tuple of 2 integers (Nx, Ny) or an instance of AutoDimMode')
 
-
     sol = fd.RealField2D(Lx, Ly, Nx, Ny)
     liq = fd.RealField2D(Lx, Ly, Nx, Ny)
 
-    Xr = np.cos(theta) * sol.X - np.sin(theta) * sol.Y
-    Yr = np.sin(theta) * sol.X + np.cos(theta) * sol.Y
+    Xr = np.cos(theta) * sol.x - np.sin(theta) * sol.y
+    Yr = np.sin(theta) * sol.x + np.cos(theta) * sol.y
 
     Ir = (Xr / Lx0 * Nx0).astype(int) % Nx0
     Jr = (Yr / Ly0 * Ny0).astype(int) % Ny0
@@ -204,40 +205,6 @@ def generate_from_field(
     return theta, sol, liq
 
 
-
-# generate a minimized solid profile for mu=0.195 eps=0.1
-@deprecated('use generate_eps instead')
-def generate_195(na, nb, Nx, Ny):
-    theta, Lx, Ly = generate(na, nb)
-    unit = np.load('saved_profiles/unit_cell_0.1950_512.npz')
-
-    Lx0 = unit['Lx']
-    Ly0 = unit['Ly']
-    Nx0 = unit['psi'].shape[0]
-    Ny0 = unit['psi'].shape[1]
-
-    x0 = np.linspace(0, Lx0, Nx0)
-    y0 = np.linspace(0, Ly0, Ny0)
-    X0, Y0 = np.meshgrid(x0, y0, indexing='ij')
-    PSI0 = unit['psi']
-
-    x = np.linspace(0, Lx, Nx)
-    y = np.linspace(0, Ly, Ny)
-    X, Y = np.meshgrid(x, y, indexing='ij')
-
-
-    Xr = np.cos(theta) * X - np.sin(theta) * Y    
-    Yr = np.sin(theta) * X + np.cos(theta) * Y    
-
-    Ir = (Xr / Lx0 * Nx0).astype(int) % Nx0
-    Jr = (Yr / Ly0 * Ny0).astype(int) % Ny0
-    
-    
-    PSI = PSI0[Ir,Jr] 
-    
-
-    return X, Y, PSI, Lx, Ly, theta, unit
-
 def harmonic(theta, x, y):
     k1 = (np.cos(theta), np.sin(theta))
     k2 = (np.cos(theta+2*np.pi/3), np.sin(theta+2*np.pi/3))
